@@ -106,13 +106,13 @@ class Geofences(_Endpoint):
         https://radar.io/documentation/api#list-geofences
 
         Args:
-            limit (int, optional): max number of geofences to return. Defaults to 100.
-            createdBefore (datetime, optional): pagination cursor. Defaults to None.
-            createdAfter (datetime, optional): pagination cursor. Defaults to None.
-            tag (str, optional): lists geofences with specified tag. Defaults to None.
+            limit (int, optional (default=100)): max number of geofences to return.
+            createdBefore (datetime, optional (default=None)): pagination cursor.
+            createdAfter (datetime, optional (default=None)): pagination cursor.
+            tag (str, optional (default=None)): lists geofences with specified tag.
 
         Returns:
-            [obj:`list` of :obj:`Geofence`]
+            `list` of :class:`~radar.models.geofence.Geofence`
         """
         path = API_PATH["geofences"]
         params = {
@@ -132,7 +132,7 @@ class Geofences(_Endpoint):
         https://radar.io/documentation/api#get-geofence
 
         Returns:
-            [:obj:`Geofence`]: instance of fetched geofence
+            :class:`~radar.models.geofence.Geofence`
         """
         if id is not None:
             path = API_PATH["geofence_id"].format(id=id)
@@ -160,7 +160,7 @@ class Geofences(_Endpoint):
         https://radar.io/documentation/api#list-geofence-users
 
         Returns:
-            [obj:`list` of :obj:`User`]
+            `list` of :class:`~radar.models.user.User`
         """
         if id is not None:
             path = API_PATH["geofence_id_users"].format(id=id)
@@ -183,7 +183,11 @@ class Geofences(_Endpoint):
         If a geofence with the specified tag and externalId already exists, the request
         will fail.
 
-        https://radar.io/documentation/api#create-geofence"""
+        https://radar.io/documentation/api#create-geofence
+        
+        Returns:
+            :class:`~radar.models.geofence.Geofence`
+        """
         self._check_required_keys_exist(data)
         path = API_PATH["geofences"]
 
@@ -196,7 +200,11 @@ class Geofences(_Endpoint):
         If a geofence with the specified tag and externalId already exists, it will be
         updated. If not, it will be created.
 
-        https://radar.io/documentation/api#upsert-geofence"""
+        https://radar.io/documentation/api#upsert-geofence
+        
+        Returns:
+            :class:`~radar.models.geofence.Geofence`
+        """
         self._check_required_keys_exist(data)
         path = API_PATH["geofence_tag"].format(tag=tag, externalId=externalId)
 
@@ -230,14 +238,14 @@ class Users(_Endpoint):
         https://radar.io/documentation/api#list-users
 
         Args:
-            limit (integer, optional): Max number of users to return. Defaults to 100.
+            limit (int, optional (default=100)): Max number of users to return.
             updateBefore (datetime, optional): A cursor for use in pagination. 
                 Retrieves users updated before the specified datetime.
             updatedAfter (datetime, optional): A cursor for use in pagination. 
                 Retrieves users updated after the specified datetime.
 
         Returns:
-            [obj:`list` of :obj:`User`]
+            `list` of :class:`~radar.models.user.User`
         """
         path = API_PATH["users"]
         params = {
@@ -256,7 +264,7 @@ class Users(_Endpoint):
         https://radar.io/documentation/api#get-user
 
         Returns:
-            [:obj:`User`]: instance of fetched user
+            :class:`~radar.models.user.User`
         """
         user_id = id or userId or deviceId
         path = API_PATH["user_id"].format(id=user_id)
@@ -285,14 +293,14 @@ class Events(_Endpoint):
         https://radar.io/documentation/api#list-events
         
         Args:
-            limit (integer, optional): Max number of events to return. Defaults to 100.
+            limit (int, optional (default=100)): Max number of events to return.
             createdBefore (datetime, optional): A cursor for use in pagination. 
                 Retrieves events created before the specified datetime.
             createdAfter (datetime, optional): A cursor for use in pagination. 
                 Retrieves events created after the specified datetime.
 
         Returns:
-            [obj:`list` of :obj:`Event`]
+            `list` of :class:`~radar.models.event.Event`
         """
         path = API_PATH["events"]
         params = {
@@ -312,7 +320,7 @@ class Events(_Endpoint):
 
 
         Returns:
-            [:obj:`Event`]: instance of fetched event
+            :class:`~radar.models.event.Event`
         """
         path = API_PATH["event_id"].format(id=id)
 
@@ -340,13 +348,13 @@ class Events(_Endpoint):
         if value:
             if value not in [-1, 0, 1]:
                 raise RadarError(
-                    message=f"value must be one of 1 (accept), -1 (reject), 0 (unverify)"
+                    message="value must be one of 1 (accept), -1 (reject), 0 (unverify)"
                 )
         else:
             verification_options = {"accept": 1, "reject": -1, "unverify": 0}
             if verification not in verification_options:
                 raise RadarError(
-                    message=f"verification must be one of 'accept', 'reject', 'unverify'"
+                    message="verification must be one of 'accept', 'reject', 'unverify'"
                 )
             verify_value = verification_options[verification]
 
@@ -374,26 +382,22 @@ class Events(_Endpoint):
 class Context(_Endpoint):
     endpoint = "context"
 
-    def get(self, latitude=None, longitude=None, coordinates=None):
-        """Gets context for a location without sending device or user identifiers to the server. 
-        Must provide latitude and longitude together, or the pair of coordinates.
+    def get(self, coordinates):
+        """Gets context for a location without sending device or user identifiers to the server.
 
         Args:
-            latitude (float): location's latitude to get context for. A number between -90 and 90.
-            longitude (float): location's longitude to get context for. A number between -180 and 180.
             coordinates ((latitude, longitude)): the coordinates of the location
         
         Examples:
-            >>> radar.context.get(latitude=40.123, longitude=-73.456)
             >>> radar.context.get(coordinates=(40.123, -73.456))
 
         Returns:
-            [:obj:`Context`]: object with the radar context for the provided location
+            :class:`~radar.models.context.RadarContext`: object with the radar context for the provided location
         """
         if coordinates:
             (latitude, longitude) = coordinates
         if latitude is None or longitude is None:
-            raise RadarError(message=f"Latitude and longitude are required")
+            raise RadarError(message="Coordinates as (latitude,longitude) are required")
 
         path = API_PATH["context"]
         params = {"coordinates": f"{latitude},{longitude}"}
@@ -413,10 +417,10 @@ class Geocode(_Endpoint):
         https://radar.io/documentation/api#geocode-forward
 
         Args:
-            query (string): The address to geocode.
+            query (str): The address to geocode.
         
         Returns:
-            list of [:obj:`Address`]
+            `list` of :class:`~radar.models.address.Address`
         """
         path = API_PATH["geocode_forward"]
         params = {"query": query}
@@ -425,23 +429,21 @@ class Geocode(_Endpoint):
         # TODO move to single address if this changes?
         return [Address(self._radar, data) for data in raw_addresses]
 
-    def reverse(self, latitude=None, longitude=None, coordinates=None):
+    def reverse(self, coordinates):
         """Reverse geocodes a location, converting coordinates to address.
         
         https://radar.io/documentation/api#geocode-reverse
 
         Args:
-            latitude (float): coordinate's latitude to reverse geocode. A number between -90 and 90.
-            longitude (float): coordinate's longitude to reverse geocode. A number between -180 and 180.
             coordinates ((latitude, longitude)): the coordinates to reverse geocode
 
         Returns:
-            list of [:obj:`Address`]
+            `list` of :class:`~radar.models.address.Address`
         """
         if coordinates:
             (latitude, longitude) = coordinates
         if latitude is None or longitude is None:
-            raise RadarError(message=f"Latitude and longitude are required")
+            raise RadarError(message="Coordinates as (latitude,longitude) are required")
 
         path = API_PATH["geocode_reverse"]
         params = {"coordinates": f"{latitude},{longitude}"}
@@ -450,33 +452,22 @@ class Geocode(_Endpoint):
         # TODO move to single address if this changes?
         return [Address(self._radar, data) for data in raw_addresses]
 
-    def ip(self, ip=None):
+    def ip(self, ip):
         """Geocodes an IP address, converting IP address to country.
         
         https://radar.io/documentation/api#geocode-ip
 
         Args:
-            ip (str, optional):  The IP address to geocode. Defaults to the request IP.
+            ip (str):  The IP address to geocode.
         
         Returns:
-            [:obj:`Regions`]
+            `list` of :class:`~radar.models.address.Address`
         """
-        if ip is None:
-            try:
-                import requests
-
-                ip = requests.get("https://checkip.amazonaws.com").text.strip()
-            except:
-                raise RadarError(
-                    message="Failed to get current ip, please provide an ip address"
-                )
-
         path = API_PATH["geocode_ip"]
         params = {"ip": ip}
 
-        raw_regions = self._get(path, params=params)
-        # TODO move to single address if this changes?
-        return Regions(self._radar, raw_regions)
+        raw_address = self._get(path, params=params)
+        return Address(self._radar, raw_address)
 
 
 class Search(_Endpoint):
@@ -489,11 +480,11 @@ class Search(_Endpoint):
 
         Args:
             near ((latitude, longitude)): A location for the search. pair of latitude,longitude.
-            radius (int, optional): The radius to search, in meters. A number between 100 and 10000. Defaults to 1000.
-            limit (int, optional): The max number of places to return. A number between 1 and 1000. Defaults to 100.
+            radius (int, optional (default=1000)): The radius to search, in meters. A number between 100 and 10000.
+            limit (int, optional (default=100)): The max number of places to return. A number between 1 and 1000.
         
         Returns:
-            list of [:obj:`User`]
+            `list` of :class:`~radar.models.user.User`
         """
         path = API_PATH["search_users"]
         (latitude, longitude) = near
@@ -511,11 +502,11 @@ class Search(_Endpoint):
         Args:
             near ((latitude, longitude)): A location for the search in the format (latitude,longitude).
             tags (str, optional): The tags to filter. A string, comma-separated.
-            radius (int, optional): The radius to search, in meters. A number between 100 and 10000. Defaults to 1000.
-            limit (int, optional): The max number of geofences to return. A number between 1 and 1000. Defaults to 100.
+            radius (int, optional (default=1000)): The radius to search, in meters. A number between 100 and 10000.
+            limit (int, optional (default=100)): The max number of geofences to return. A number between 1 and 1000.
         
         Returns:
-            list of [:obj:`Geofence`]
+            `list` of :class:`~radar.models.geofence.Geofence`
         """
         path = API_PATH["search_geofences"]
         (latitude, longitude) = near
@@ -542,11 +533,11 @@ class Search(_Endpoint):
             chains (str, optional): The chain slugs to filter. A string, comma-separated.
             categories (str, optional): The categories to filter. A string, comma-separated.
             groups (str, optional): The groups to filter. A string, comma-separated.
-            radius (int, optional): The radius to search, in meters. A number between 100 and 10000. Defaults to 1000.
-            limit (int, optional): The max number of places to return. A number between 1 and 1000. Defaults to 100.
+            radius (int, optional (default=1000)): The radius to search, in meters. A number between 100 and 10000.
+            limit (int, optional (default=100)): The max number of places to return. A number between 1 and 1000.
 
         Returns:
-            list of [:obj:`Place`]
+            `list` of :class:`~radar.models.place.Place`
         
         Example:
             >>> radar.search.places(query="brooklyn roasting", near=(40.7041029,-73.98706))
@@ -573,12 +564,12 @@ class Search(_Endpoint):
         https://radar.io/documentation/api#search-autocomplete
 
         Args:
-            query (string): The partial address or place name to autocomplete.
+            query (str): The partial address or place name to autocomplete.
             near ((latitude,longitude)): A location for the search in the format (latitude,longitude).
-            limit (int, optional): The max number of addresses to return. A number between 1 and 100. Defaults to 10.
+            limit (int, optional (default=10)): The max number of addresses to return. A number between 1 and 100.
 
         Returns:
-            list of [:obj:`Address`]
+            `list` of :class:`~radar.models.address.Address`
         
         Example:
             >>> radar.search.autocomplete(near=(40.7041029,-73.98706), categories="coffee-shop")
@@ -609,13 +600,13 @@ class Route(_Endpoint):
         https://radar.io/documentation/api#route-distance
 
         Args:
-            origin (string): The origin. A string in the format latitude,longitude.
-            destination (string): The destination. A string in the format latitude,longitude.
-            modes (string): The travel modes. A string, comma-separated, including one or more of foot, bike, car, and transit.
-            units (string, optional): The distance units. A string, metric or imperial. Defaults to metric
+            origin (str): The origin. A string in the format latitude,longitude.
+            destination (str): The destination. A string in the format latitude,longitude.
+            modes (str): The travel modes. A string, comma-separated, including one or more of foot, bike, car, and transit.
+            units (str, optional (default="metric")): The distance units. A string, metric or imperial.
         
         Returns:
-            [:obj:`Routes`]
+            :class:`~radar.models.route.Routes`
         """
         path = API_PATH["route_distance"]
         (origin_lat, origin_lng) = origin
@@ -628,7 +619,7 @@ class Route(_Endpoint):
         MODE_OPTIONS = ["car", "bike", "transit", "foot"]
         if not all([mode in MODE_OPTIONS for mode in modes.split(",")]):
             raise RadarError(
-                message=f"modes must be comma-separated string including one or more of 'foot,bike,car,transit'"
+                message="modes must be comma-separated string including one or more of 'foot,bike,car,transit'"
             )
 
         query_params = {
